@@ -21,7 +21,7 @@ let split ?(sep = [' ';'\t';'\r';'\n']) s =
     else loop last next acc
   in List.rev (loop 0 0 [])
 
-let lablgtk_mls = split "gaux gpointer gutf8 glib gobject gdkEnums pangoEnums gtkEnums pango gdk gdkEvent gdkKeysyms gdkPixbuf gtk gtkSignal gtkStock gtkObject gtkBaseProps gtkBinProps gtkButtonProps gtkEditProps gtkListProps gtkMenuProps gtkMiscProps gtkPackProps gtkRangeProps gtkTextProps gtkTreeProps gtkFileProps gtkActionProps gtkBrokenProps gtkAssistantProps gtkData gtkBase gtkPack gtkButton gtkAssistant gtkMenu gtkMisc gtkWindow gtkList gtkBin gtkEdit gtkRange gtkText gtkTree gtkFile gtkMain gtkBroken gPango gDraw gObj gData gMain ogtkBaseProps ogtkBinProps ogtkButtonProps ogtkEditProps ogtkListProps ogtkMenuProps ogtkMiscProps ogtkPackProps ogtkRangeProps ogtkTextProps ogtkTreeProps ogtkFileProps ogtkActionProps ogtkBrokenProps ogtkAssistantProps gContainer gPack gButton gText gMenu gMisc gTree gList gFile gWindow gAssistant gBin gEdit gRange gAction gBroken gUtil gToolbox"
+let lablgtk_mls = split "gaux gpointer gutf8 glib gobject gdkEnums pangoEnums gtkEnums pango gdk gdkEvent gdkKeysyms gdkPixbuf gtk gtkSignal gtkStock gtkObject gtkBaseProps gtkBinProps gtkButtonProps gtkEditProps gtkListProps gtkMenuProps gtkMiscProps gtkPackProps gtkRangeProps gtkTextProps gtkTreeProps gtkFileProps gtkActionProps gtkBrokenProps gtkAssistantProps gtkData gtkBase gtkPack gtkButton gtkAssistant gtkMenu gtkMisc gtkWindow gtkList gtkBin gtkEdit gtkRange gtkText gtkTree gtkFile gtkMain gtkBroken gPango gDraw gObj ogtkBaseProps gData ogtkBaseProps ogtkBinProps ogtkButtonProps ogtkEditProps ogtkListProps ogtkMenuProps ogtkMiscProps ogtkPackProps ogtkRangeProps ogtkTextProps ogtkTreeProps ogtkFileProps ogtkActionProps ogtkBrokenProps ogtkAssistantProps gMain gContainer gPack gButton gText gMenu gMisc gTree gList gFile gWindow gAssistant gBin gEdit gRange gAction gBroken gUtil gToolbox"
 let extra_mls = split "gtkInit gtkThread gtkThInit"
 let prop_mls = split "gtkBaseProps gtkBinProps gtkButtonProps gtkEditProps gtkListProps gtkMenuProps gtkMiscProps gtkPackProps gtkRangeProps gtkTextProps gtkTreeProps gtkFileProps gtkActionProps gtkBrokenProps gtkAssistantProps ogtkBaseProps ogtkBinProps ogtkButtonProps ogtkEditProps ogtkListProps ogtkMenuProps ogtkMiscProps ogtkPackProps ogtkRangeProps ogtkTextProps ogtkTreeProps ogtkFileProps ogtkActionProps ogtkBrokenProps ogtkAssistantProps"
 let gtk_libs = "-L/usr/local/lib -L/usr/X11R6/lib -Wl,-rpath-link,/usr/X11R6/lib -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -lXrender -lXinerama -lXi -lXrandr -lXcursor -lXcomposite -lXdamage -lXfixes -lX11 -lXext -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lm -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype -lz"
@@ -31,6 +31,8 @@ let rsvg_mls = split "rsvg"
 let rsvg_libs = "-L/usr/local/lib -Wl,-rpath-link,/usr/X11R6/lib -lrsvg-2 -lm -lgio-2.0 -lgdk_pixbuf-2.0 -lgobject-2.0 -lglib-2.0 -lintl -lcairo"
 let canvas_mls = split "gnomeCanvas gnoCanvas"
 let canvas_libs = "-L/usr/local/lib -L/usr/X11R6/lib -Wl,-rpath-link,/usr/X11R6/lib -lgnomecanvas-2 -lart_lgpl_2 -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -lXrender -lXinerama -lXi -lXrandr -lXcursor -lXcomposite -lXdamage -lXfixes -lX11 -lXext -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lm -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype -lz"
+let sourceview2_mls = split "sourceView2Enums gtkSourceView2Props ogtkSourceView2Props gtkSourceView2 gSourceView2"
+let sourceview2_libs = "-L/usr/local/lib -L/usr/X11R6/lib -Wl,-rpath-link,/usr/X11R6/lib -lgtksourceview-2.0 -lgtk-x11-2.0 -lgdk-x11-2.0 -lpangocairo-1.0 -lXrender -lXinerama -lXi -lXrandr -lXcursor -lXcomposite -lXdamage -lXfixes -lX11 -lXext -latk-1.0 -lcairo -lgdk_pixbuf-2.0 -lgio-2.0 -lpangoft2-1.0 -lpango-1.0 -lm -lgobject-2.0 -lglib-2.0 -lintl -lfontconfig -lfreetype -lz"
 
 (* Hack to check for mingw *)
 let () =
@@ -75,18 +77,20 @@ let may_remove f =
   if Sys.file_exists f then Sys.remove f
 
 type descr =
-    { mls: string list; extra: string list; libs: string;
+    { mlis: string list; mls: string list; extra: string list; libs: string;
       name: string; cname: string }
 
 let libs =
-  let lib ~mls ~libs ~name ?(extra=[]) ?(cname=name) () =
-    {mls=mls; extra=extra; libs=rename_libs libs; name=name; cname=cname} in
+  let lib ~mls ~libs ~name ?(extra=[]) ?(mlis=[]) ?(cname=name) () =
+    {mlis; mls; extra; libs=rename_libs libs; name; cname} in
   [ lib ~mls:lablgtk_mls ~extra:extra_mls ~libs:gtk_libs ~name:"lablgtk"
        ~cname:"lablgtk2" ();
     lib ~mls:glade_mls ~libs:glade_libs ~name:"lablglade"
        ~cname:"lablglade2" ();
     lib ~mls:rsvg_mls ~libs:rsvg_libs ~name:"lablrsvg" ();
-    lib ~mls:canvas_mls ~libs:canvas_libs ~name:"lablgnomecanvas" ()]
+    lib ~mls:canvas_mls ~libs:canvas_libs ~name:"lablgnomecanvas" ();
+    lib ~mls:sourceview2_mls ~libs:sourceview2_libs
+        ~name:"lablgtksourceview2" ~mlis:["gtkSourceView2_types"] ()]
 
 let compopts = []
   (*["gtkSignal",
@@ -98,6 +102,7 @@ let compile ~comp file =
 
 let byte d =
   if d.mls <> [] then begin
+    List.iter d.mlis ~f:(fun file -> exe !ocamlc ["-c"; file^".mli"]);
     List.iter (d.mls @ d.extra) ~f:
       begin fun file ->
 	if Sys.file_exists (file ^ ".mli") then exe !ocamlc ["-c"; file^".mli"];
